==> postfixadmin-3.3.8-1-any.pkg.tar.xz: usr/share/webapps/postfixadmin/languages/language.php <==
<?php if (!defined('POSTFIXADMIN')) {
    die("This file cannot be used standalone.");
} ?>
<?php
# List of supported languages
$supported_languages = array(
#   Format:
#   'code'  => 'native language name - language name in english'
    'bg'    => '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080; - Bulgarian',
    'ca'    => 'Catal&agrave; - Catalan',
    'cn'    => '&#20013;&#25991; - Chinese simplified (gb2312)',
    'tw'    => '&#20013;&#25991; - Chinese traditional',
    'cs'    => '&#268;esky - Czech',
    'da'    => 'Dansk - Danish',
    'de'    => 'Deutsch - German',
    'en'    => 'English',
    'es'    => 'Espa&ntilde;ol - Spanish',
    'et'    => 'Eesti - Estonian',
    'eu'    => 'Euskara - Basque',
    'fi'    => 'Suomi - Finnish',
    'fo'    => 'Faroese',
    'fr'    => 'Fran&ccedil;ais - French',
    'hr'    => 'Hrvatski - Croatian',
    'hu'    => 'Magyar - Hungarian',
    'gl'    => 'Galego - Galician',
    'is'    => 'Icelandic',
    'it'    => 'Italiano - Italian',
    'ja'    => '&#26085;&#26412;&#35486; - Japanese',
    'lt'    => 'Lietuvi&#371; - Lithuanian',
    'mk'    => 'Macedonian - Macedonian',
    'nl'    => 'Nederlands - Dutch',
    'nb'    => 'Norsk (bokm&#229;l) - Norwegian (bokm&#229;l)',
    'nn'    => 'Norsk (nynorsk) - Norwegian (nynorsk)',
    'pl'    => 'Polski - Polish',
    'pt-br' => 'Portugu&ecirc;s - Brazilian portuguese',
    'pt-pt' => 'Portugu&ecirc;s - European portuguese',
    'ro'    => 'Limba Rom&acirc;n&#259; - Romanian',
    'ru'    => '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081; - Russian',
    'sk'    => 'Sloven&#269;ina - Slovak',
    'sl'    => 'Sloven&scaron;&#269;ina - Slovenian',
    'sv'    => 'Svenska - Swedish',
    'tr'    => 'T&uuml;rk&ccedil;e - Turkish',
    'ua'    => '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072 - Ukrainian',
);

/* vim: set expandtab ft=php softtabstop=4 tabstop=4 shiftwidth=4: */
?>

==> postfixadmin-3.3.11-1-any.pkg.tar.xz: usr/share/webapps/postfixadmin/languages/language.php <==
<?php if (!defined('POSTFIXADMIN')) {
    die("This file cannot be used standalone.");
} ?>
<?php
# List of supported languages
$supported_languages = array(
#   Format:
#   'code'  => 'native language name - language name in english'
    'bg'    => '&#1041;&#1098;&#1083;&#1075;&#1072;&#1088;&#1089;&#1082;&#1080; - Bulgarian',
    'ca'    => 'Catal&agrave; - Catalan',
    'cn'    => '&#20013;&#25991; - Chinese simplified (gb2312)',
    'tw'    => '&#20013;&#25991; - Chinese traditional',
    'cs'    => '&#268;esky - Czech',
    'da'    => 'Dansk - Danish',
    'de'    => 'Deutsch - German',
    'en'    => 'English',
    'es'    => 'Espa&ntilde;ol - Spanish',
    'et'    => 'Eesti - Estonian',
    'eu'    => 'Euskara - Basque',
    'fi'    => 'Suomi - Finnish',
    'fo'    => 'Faroese',
    'fr'    => 'Fran&ccedil;ais - French',
    'hr'    => 'Hrvatski - Croatian',
    'hu'    => 'Magyar - Hungarian',
    'gl'    => 'Galego - Galician',
    'is'    => 'Icelandic',
    'it'    => 'Italiano - Italian',
    'ja'    => '&#26085;&#26412;&#35486; - Japanese',
    'lt'    => 'Lietuvi&#371; - Lithuanian',
    'mk'    => 'Macedonian - Macedonian',
    'nl'    => 'Nederlands - Dutch',
    'nb'    => 'Norsk (bokm&#229;l) - Norwegian (bokm&#229;l)',
    'nn'    => 'Norsk (nynorsk) - Norwegian (nynorsk)',
    'pl'    => 'Polski - Polish',
    'pt-br' => 'Portugu&ecirc;s - Brazilian portuguese',
    'pt-pt' => 'Portugu&ecirc;s - European portuguese',
    'ro'    => 'Limba Rom&acirc;n&#259; - Romanian',
    'ru'    => '&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081; - Russian',
    'sk'    => 'Sloven&#269;ina - Slovak',
    'sl'    => 'Sloven&scaron;&#269;ina - Slovenian',
    'sv'    => 'Svenska - Swedish',
    'tr'    => 'T&uuml;rk&ccedil;e - Turkish',
    'ua'    => '&#1059;&#1082;&#1088;&#1072;&#1111;&#1085;&#1089;&#1100;&#1082;&#1072; - Ukrainian',
);

/* vim: set expandtab ft=php softtabstop=4 tabstop=4 shiftwidth=4: */
?>
